@@ -1,5 +1,5 @@
 package POE::Component::DebugShell;
-# $Header: /home/sungo/src/sungo/POE-Component-DebugShell/lib/POE/Component/DebugShell.pm,v 1.18 2004/03/07 01:45:47 sungo Exp $
+# $Header: /cvsroot/sungo/POE-Component-DebugShell/lib/POE/Component/DebugShell.pm,v 1.14 2004/02/27 00:38:27 sungo Exp $
 
 use warnings;
 use strict;
@@ -12,7 +12,8 @@ use POE;
 use POE::Wheel::ReadLine;
 use POE::API::Peek;
 
-our $VERSION = '1.'.sprintf "%04d", (qw($Rev: 411 $))[1];
+
+our $VERSION = (qw($Revision: 1.14 $))[1];
 our $RUNNING = 0;
 our %COMMANDS;
 our $SPAWN_TIME;
@@ -29,6 +30,7 @@ sub spawn { #{{{
     }
     # }}}
 
+    
     my $api = POE::API::Peek->new() or croak "Unable to create POE::API::Peek object";
 
 
@@ -57,17 +59,13 @@ sub spawn { #{{{
 
 
 sub _start { #{{{
-    $_[KERNEL]->alias_set(__PACKAGE__." controller");
-
+    $_[KERNEL]->alias_set(__PACKAGE__." controller");    
     $_[HEAP]->{rl} = POE::Wheel::ReadLine->new( InputEvent => 'term_input' );
     $_[HEAP]->{prompt} = 'debug> ';
-
-    tie *STDOUT, "POE::Component::DebugShell::Output", 'stdout', \&_output;
-    tie *STDERR, "POE::Component::DebugShell::Output", 'stderr', \&_output;
-
+    
     $_[HEAP]->{rl}->clear();
     _output("Welcome to POE Debug Shell v$VERSION");
-
+    
     $_[HEAP]->{rl}->get($_[HEAP]->{prompt});
 
 } #}}}
@@ -110,10 +108,10 @@ sub term_input { #{{{
         foreach my $cmd (sort keys %COMMANDS) {
             no warnings;
             my $short_help = $COMMANDS{$cmd}{short_help} || '[ No short help provided ]';
-            _output("\t* $cmd - $short_help");
+            _output("\t* $cmd - $short_help"); 
         }
         _output(' ');
-
+        
     } else  {
         my ($cmd, @args);
         if($input =~ /^(.+?)\s+(.*)$/) {
@@ -125,12 +123,9 @@ sub term_input { #{{{
         }
 
         if($COMMANDS{$cmd}) {
-            my $txt = eval { $COMMANDS{$cmd}{cmd}->( api => $_[HEAP]->{api}, args => \@args); };
+            eval { $COMMANDS{$cmd}{cmd}->( api => $_[HEAP]->{api}, args => \@args); };
             if($@) {
                 _output("Error running $cmd: $@");
-            } else {
-                my @lines = split(/\n/, $txt);
-                _output($_) for @lines;
             }
         } else {
             _output("Error: '$cmd' is not a known command");
@@ -138,20 +133,17 @@ sub term_input { #{{{
     }
 
     $_[HEAP]->{rl}->get($_[HEAP]->{prompt});
-
+       
 } #}}}
 
 
 
 sub _output { #{{{
     my $msg = shift || ' ';
-    my $heap = $poe_kernel->alias_resolve(__PACKAGE__." controller")->get_heap(); 
+    my $heap = $poe_kernel->get_active_session->get_heap;
     $heap->{rl}->put($msg);
 } #}}}
 
-sub _raw_commands { #{{{
-    return \%COMMANDS;
-} #}}}
 
 #   ____                                          _     
 #  / ___|___  _ __ ___  _ __ ___   __ _ _ __   __| |___ 
@@ -163,12 +155,18 @@ sub _raw_commands { #{{{
 
 %COMMANDS = ( #{{{
 
+    'exit' => {
+        help => "Exit the shell",
+        short_help => 'Exit the shell',
+        cmd => \&cmd_exit,      
+    },
+
     'reload' => {
         help => "Reload the shell to catch updates.",
         short_help => "Reload the shell to catch updates.",
         cmd => \&cmd_reload,
     },
-
+    
     show_sessions => {
         help => 'Show a list of all sessions in the system. The output format is in the form of loggable session ids.',
         short_help => 'Show a list of all sessions',
@@ -202,68 +200,67 @@ sub _raw_commands { #{{{
 
 ###############
 
+sub cmd_exit { #{{{
+    _output('Exiting...');
+    exit;
+} #}}}
+
 sub cmd_reload { #{{{
-    my $ret;
-    $ret .= "Reloading....\n";
-    eval q|
-        no warnings qw(redefine);
-        $SIG{__WARN__} = sub { };
-
-        foreach my $key (keys %INC) {
-            if($key =~ m#POE/Component/DebugShell#) {
-                delete $INC{$key};
-            } elsif ($key =~ m#POE/API/Peek#) {
-                delete $INC{$key};
+    {
+        _output("Reloading....");
+        eval q|
+            no warnings qw(redefine);
+            $SIG{__WARN__} = sub { };
+            
+            foreach my $key (keys %INC) {
+                if($key =~ m#POE/Component/DebugShell#) {
+                    delete $INC{$key};
+                } elsif ($key =~ m#POE/API/Peek#) {
+                    delete $INC{$key};
+                }
             }
-        }
-        require POE::Component::DebugShell;
-    |;
-    $ret .= "Error: $@\n" if $@;
-
-    return $ret;
+            require POE::Component::DebugShell;
+        |;
+        _output("Error: $@") if $@;
+    }
 } #}}}
 
 sub cmd_show_sessions { #{{{
     my %args = @_;
     my $api = $args{api};
-
-    my $ret;
-    $ret .= "Session List:\n";
+     
+    _output("Session List:");
     my @sessions = $api->session_list;
     foreach my $sess (@sessions) {
+        
         my $id = $sess->ID. " [ ".$api->session_id_loggable($sess)." ]";
-        $ret .= "\t* $id\n";
+        _output("\t* $id");
     }
-
-    return $ret;
 } #}}}
 
 sub cmd_list_aliases { #{{{
     my %args = @_;
     my $user_args = $args{args};
     my $api = $args{api};
-
-    my $ret;
-
+    
     if(my $id = shift @$user_args) {
         if(my $sess = $api->resolve_session_to_ref($id)) {
             my @aliases = $api->session_alias_list($sess);
             if(@aliases) {
-                $ret .= "Alias list for session $id\n";
+                _output("Alias list for session $id");
                 foreach my $alias (sort @aliases) {
-                    $ret .= "\t* $alias\n";
+                    _output("\t* $alias");
                 }
             } else {
-                $ret .= "No aliases found for session $id\n";
+                _output("No aliases found for session $id");
             }
         } else {
-            $ret .= "** Error: ID $id does not resolve to a session. Sorry.\n";
+            _output("** Error: ID $id does not resolve to a session. Sorry.");
         }
 
     } else {
-        $ret .= "** Error: Please provide a session id\n";
+        _output("** Error: Please provide a session id");
     }
-    return $ret;
 }
 
 # }}}
@@ -272,105 +269,72 @@ sub cmd_session_stats { #{{{
     my %args = @_;
     my $user_args = $args{args};
     my $api = $args{api};
-
-    my $ret;
-
     if(my $id = shift @$user_args) {
         if(my $sess = $api->resolve_session_to_ref($id)) {
             my $to = $api->event_count_to($sess);
             my $from = $api->event_count_from($sess);
-            $ret .= "Statistics for Session $id\n";
-            $ret .= "\tEvents coming from: $from\n";
-            $ret .= "\tEvents going to: $to\n";
-
+            _output("Statistics for Session $id");
+            _output("\tEvents coming from: $from");
+            _output("\tEvents going to: $to");
+            
         } else {
-            $ret .= "** Error: ID $id does not resolve to a session. Sorry.\n";
+            _output("** Error: ID $id does not resolve to a session. Sorry.");
         }
 
 
     } else {
-        $ret .= "** Error: Please provide a session id\n";
+        _output("** Error: Please provide a session id");
     }
+    
 
-    return $ret;
 } #}}}
 
 sub cmd_queue_dump { #{{{
     my %args = @_;
     my $api = $args{api};
     my $verbose;
-
-    my $ret;
-
-    if($args{args} && defined $args{args}) {
-        if(ref $args{args} eq 'ARRAY') {
-            if(@{$args{args}}[0] eq '-v') {
-                $verbose = 1;
-            }
-        }
+    if(defined $args{args} && (@{$args{args}}[0] eq '-v')) {
+        $verbose = 1;
     }
-
+    
     my @queue = $api->event_queue_dump();
-
-    $ret .= "Event Queue:\n";
-
+    
+    _output("Event Queue:");
+  
     foreach my $item (@queue) {
-        $ret .= "\t* ID: ". $item->{ID}." - Index: ".$item->{index}."\n";
-        $ret .= "\t\tPriority: ".$item->{priority}."\n";
-        $ret .= "\t\tEvent: ".$item->{event}."\n";
+        _output("\t* ID: ". $item->{ID}." - Index: ".$item->{index});
+        _output("\t\tPriority: ".$item->{priority});
+        _output("\t\tEvent: ".$item->{event});
 
         if($verbose) {
-            $ret .= "\t\tSource: ".
-                    $api->session_id_loggable($item->{source}).
-                    "\n";
-            $ret .= "\t\tDestination: ".
-                    $api->session_id_loggable($item->{destination}).
-                    "\n";
-            $ret .= "\t\tType: ".$item->{type}."\n";
-            $ret .= "\n";
+            _output("\t\tSource: ".
+                    $api->session_id_loggable($item->{source})
+                   );
+            _output("\t\tDestination: ".
+                    $api->session_id_loggable($item->{destination})
+                   );
+            _output("\t\tType: ".$item->{type});
+
+            _output();
         }
     }
-    return $ret;
+
 } #}}}
 
 sub cmd_status { #{{{
     my %args = @_;
     my $api = $args{api};
     my $sess_count = $api->session_count;
-    my $ret = "\n";
-    $ret .= "This is ".__PACKAGE__." v".$VERSION."\n";
-    $ret .= "running inside $0."."\n";
-    $ret .= "This console was spawned at ".localtime($SPAWN_TIME).".\n";
-    $ret .= "There are $sess_count known sessions (including the kernel).\n";
-    $ret .= "\n";
-    return $ret;
+    _output();
+    _output("This is ".__PACKAGE__." v".$VERSION);
+    _output("running inside $0.");
+    _output("This console was spawned at ".localtime($SPAWN_TIME).'.');
+    _output("There are $sess_count known sessions (including the kernel),");
+    _output();
 } # }}}
 
 # }}}
 
-1;
-
-package POE::Component::DebugShell::Output;
-
-use strict;
-#use warnings FATAL => "all";
-
-sub PRINT { 
-    my $self = shift;
-
-    my $txt = join('',@_);
-    $txt =~ s/\r?\n$//;
-    $self->{print}->($self->{type}."> $txt");
-}
-
-sub TIEHANDLE {
-    my $class = shift;
-    bless({
-        type => shift,
-        print => shift,
-    }, $class);
-}
-
 1;
 __END__
 
@@ -389,115 +353,10 @@ running POE application
 
 =head1 DESCRIPTION
 
-This component allows for interactive peeking into a running POE
-application.
+This component allows for interactive peeking into a running POE application.
 
-C<spawn()> creates a ReadLine enabled shell equipped with various debug
-commands. The following commands are available.
 
-=head1 COMMANDS
-
-=head2 show_sessions
-
- debug> show_sessions
-    * 3 [ session 3 (POE::Component::DebugShell controller) ]
-    * 2 [ session 2 (PIE, PIE2) ]
-
-Show a list of all sessions in the system. The output format is in the
-form of loggable session ids.
-
-=head2 session_stats
-
- debug> session_stats 2
-    Statistics for Session 2
-        Events coming from: 1
-        Events going to: 1
-
-Display various statistics for a given session. Provide one session id
-as a parameter.
-
-=head2 list_aliases
-
- debug> list_aliases 2
-    Alias list for session 2
-        * PIE
-        * PIE2
-
-List aliases for a given session id. Provide one session id as a
-parameter.
-
-=head2 queue_dump
-
- debug> queue_dump
-    Event Queue:
-        * ID: 738 - Index: 0
-            Priority: 1078459009.06715
-            Event: _sigchld_poll
-        * ID: 704 - Index: 1
-            Priority: 1078459012.42691
-            Event: ping
-
-Dump the contents of the event queue. Add a C<-v> parameter to get
-verbose output.
-
-=head2 help
-
- debug> help
-    The following commands are available:
-        ...
-
-Display help about available commands.
-
-=head2 status
-
- debug> status
-    This is POE::Component::DebugShell v1.14
-    running inside examples/foo.perl.
-    This console spawned at Thu Mar 4 22:51:51 2004.
-    There are 3 known sessions (including the kernel).
-
-General shell status.
-
-=head2 reload
-
- debug> reload
- Reloading...
-
-Reload the shell
-
-=head2 exit
-
- debug> exit
- Exiting...
-
-Exit the shell
-
-=head1 DEVELOPERS
-
-For you wacky developers, I've provided access to the raw command data
-via the C<_raw_commands> method. The underbar at the beginning should 
-let you know that this is an experimental interface for developers only. 
-
-C<_raw_commands> returns a hash reference. The keys of this hash are the
-command names. The values are a hash of data about the command. This
-hash contains the following data:
-
-=over 4
-
-=item * short_help
-
-Short help text
-
-=item * help
-
-Long help text
-
-=item * cmd
-
-Code reference for the command. This command requires that a hash be
-passed to it containing an C<api> parameter, which is a 
-C<POE::API::Peek> object, and an C<args> parameter, which is an array
-reference of arguments (think C<@ARGV>).
+=cut
 
 =head1 AUTHOR
 
@@ -505,7 +364,7 @@ Matt Cashner (cpan@eekeek.org)
 
 =head1 DATE
 
-$Date: 2004-10-14 02:21:24 -0400 (Thu, 14 Oct 2004) $
+$Date: 2004/02/27 00:38:27 $
 
 =head1 LICENSE
 
@@ -535,4 +394,4 @@ ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-# sungo // vim: ts=4 sw=4 expandtab
+
